==> spread-5.0.0.54-py3-none-any.whl: spread-5.0.0.54.data/data/spread/dashboard/static/project/project.js <==
const INFO = 'info';
const URSL = [
    'https://throne.systems/storage/',
    'https://beta.throne.systems/storage/',
    'https://alpha.throne.systems/storage/'
];

var selectedServices = [];

$(document).on('contextmenu', ' input[type=checkbox]', function (cb) {
    const checked = this.checked;
    $(this).parents('.configs').find('.panel-heading input[type=checkbox]').each(function () {
        this.checked = !checked;
        selectAll(this);
    });
    return false;
});
$(document).on('click', '.panel-heading .glyphicon', function () {
    var $this = $(this);
    $this.parents('.configs .panel').find('.panel-body').slideToggle();
    $this.toggleClass('glyphicon-chevron-down').toggleClass('glyphicon-chevron-up');
});

$(document).ready(function () {
    if (document.location.hash) {
        $('#edit-' + document.location.hash.substr(1)).click();
    } else {
        $('#info').click();
    }

    $('.columns .panel-body input[type=checkbox]').each(function () {
        if (this.checked) {
            selectedServices.push(this.name);
        }
    });
});

function selectAll(cb) {
    $(cb).parents('.columns').find('.panel-body input[type=checkbox]').each(function () {
        this.checked = cb.checked;
        onSelect(this);
    });
}
function onSelect(cb) {
    const index = selectedServices.indexOf(cb.name);
    if (cb.checked) {
        if (index === -1) {
            selectedServices.push(cb.name);
        }
    } else {
        if (index !== -1) {
            selectedServices.splice(index, 1);
        }
    }

    checkSelected();
}

function checkSelected() {
    const svField = $('#sv-actions');

    svField.find(' form').each(function () {
        this.supervisor.value = selectedServices;
    });

    svField.find('.badge').each(function () {
        this.textContent = selectedServices.length;
    });
}

function splitCode(code) {
    while (code.indexOf('-') !== -1) {
        code = code.replace('-', '');
    }
    return code;
}

function onCloudCodeChange(form) {
    var code = splitCode(form.cloudCode.value);
    var sum = 0;
    var n = parseInt(code);
    while (n > 0) {
        sum += n % 10;
        n = Math.floor(n / 10);
    }

    if (sum%10 < URSL.length) {
        form.cloudCode.setCustomValidity('');
        form.index.value = sum%10;
    } else {
        form.cloudCode.setCustomValidity('Неверный cloud-код!');
    }
}

function loadCloud(form) {
    const url = URSL[form.index.value] + splitCode(form.cloudCode.value) + '.ctp';
    // const url = 'http://10.10.1.77:8000/spread/static/project.ctp';

    var oReq = new XMLHttpRequest();
    oReq.open("GET", url, true);
    oReq.responseType = "arraybuffer";

    oReq.onload = function(e) {
        var blob = new Blob([oReq.response], {type: "application/octet-stream"});
        const reader = new FileReader();
        reader.onloadend = () => {
            var xhr = new XMLHttpRequest();
            xhr.open('POST', document.location + 'ctp/', true);
            xhr.setRequestHeader("X-CSRFToken", $('#upload-form').serialize().replace('csrfmiddlewaretoken=', ''));
            xhr.send(reader.result);
        };
        reader.readAsArrayBuffer(blob);
    };
    oReq.onerror = function() {
        console.log('Failed! Try save file...');
        const link = document.createElement('a');
        link.setAttribute('href', url);
        link.click();
    };

    oReq.send();

    // form.cloudCode.value = '';
}

function onConfig(config) {
    $.get({
        url: config,
    }).done(function (e) {
        $('#content')[0].innerHTML = e;
        if (config === INFO) {
            checkSelected();
        }
    }).fail(function (e) {
        console.log('failed');
    });
}

==> spread-5.1.0.48-py3-none-any.whl: spread-5.1.0.48.data/data/spread/dashboard/static/project/project.js <==
const INFO = 'info';
const URSL = [
    'https://throne.systems/storage/',
    'https://beta.throne.systems/storage/',
    'https://alpha.throne.systems/storage/'
];

var selectedServices = [];

$(document).on('contextmenu', ' input[type=checkbox]', function (cb) {
    const checked = this.checked;
    $(this).parents('.configs').find('.panel-heading input[type=checkbox]').each(function () {
        this.checked = !checked;
        selectAll(this);
    });
    return false;
});
$(document).on('click', '.panel-heading .glyphicon', function () {
    var $this = $(this);
    $this.parents('.configs .panel').find('.panel-body').slideToggle();
    $this.toggleClass('glyphicon-chevron-down').toggleClass('glyphicon-chevron-up');
});

$(document).ready(function () {
    if (document.location.hash) {
        $('#edit-' + document.location.hash.substr(1)).click();
    } else {
        $('#info').click();
    }

    $('.columns .panel-body input[type=checkbox]').each(function () {
        if (this.checked) {
            selectedServices.push(this.name);
        }
    });
});

function selectAll(cb) {
    $(cb).parents('.columns').find('.panel-body input[type=checkbox]').each(function () {
        this.checked = cb.checked;
        onSelect(this);
    });
}
function onSelect(cb) {
    const index = selectedServices.indexOf(cb.name);
    if (cb.checked) {
        if (index === -1) {
            selectedServices.push(cb.name);
        }
    } else {
        if (index !== -1) {
            selectedServices.splice(index, 1);
        }
    }

    checkSelected();
}

function checkSelected() {
    const svField = $('#sv-actions');

    svField.find(' form').each(function () {
        this.supervisor.value = selectedServices;
    });

    svField.find('.badge').each(function () {
        this.textContent = selectedServices.length;
    });
}

function splitCode(code) {
    while (code.indexOf('-') !== -1) {
        code = code.replace('-', '');
    }
    return code;
}

function onCloudCodeChange(form) {
    var code = splitCode(form.cloudCode.value);
    var sum = 0;
    var n = parseInt(code);
    while (n > 0) {
        sum += n % 10;
        n = Math.floor(n / 10);
    }

    if (sum%10 < URSL.length) {
        form.cloudCode.setCustomValidity('');
        form.index.value = sum%10;
    } else {
        form.cloudCode.setCustomValidity(gettext('project_bad_cloud_code'));
    }
}

function loadCloud(form) {
    const url = URSL[form.index.value] + splitCode(form.cloudCode.value) + '.ctp';
    // const url = 'http://10.10.1.77:8000/spread/static/project.ctp';

    var oReq = new XMLHttpRequest();
    oReq.open("GET", url, true);
    oReq.responseType = "arraybuffer";

    oReq.onload = function(e) {
        var blob = new Blob([oReq.response], {type: "application/octet-stream"});
        const reader = new FileReader();
        reader.onloadend = () => {
            var xhr = new XMLHttpRequest();
            xhr.open('POST', document.location + 'ctp/', true);
            xhr.setRequestHeader("X-CSRFToken", $('#upload-form').serialize().replace('csrfmiddlewaretoken=', ''));
            xhr.send(reader.result);
        };
        reader.readAsArrayBuffer(blob);
    };
    oReq.onerror = function() {
        console.log('Failed! Try save file...');
        const link = document.createElement('a');
        link.setAttribute('href', url);
        link.click();
    };

    oReq.send();

    // form.cloudCode.value = '';
}

function onConfig(config, dest) {
    $.get({
        url: config,
        data: {
            dest: dest
        }
    }).done(function (e) {
        $('#content')[0].innerHTML = e;
        if (config === INFO) {
            checkSelected();
        }
    }).fail(function (e) {
        console.log('failed');
    });
}
